#
# spec file for package python-sortedcontainers
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-sortedcontainers
Version:        1.5.9
Release:        lp151.2.3
Summary:        Sorted container data types
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://www.grantjenks.com/docs/sortedcontainers
Source:         https://files.pythonhosted.org/packages/source/s/sortedcontainers/sortedcontainers-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
SortedContainers is an Apache2 licensed containers library, written in
pure-Python, and fast as C-extensions.

Python's standard library is great until you need a sorted container type. Many
will attest that you can get really far without one, but the moment you **really
need** a sorted list, dict, or set, you're faced with a dozen different
implementations, most using C-extensions without great documentation and
benchmarking.

SortedContainers takes all of the work out of Python sorted types - making your
deployment and use of Python easy. There's no need to install a C compiler or
pre-build and distribute custom extensions. Performance is a feature and testing
has 100% coverage with unit tests and hours of stress.

%package     -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Provides:       %{python_module zope.schema-doc = %{version}}
Requires:       %{name} = %{version}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n sortedcontainers-%{version}
rm -rf sortedcontainers.egg-info

%build
%python_build
%__python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
%python_install
# We need to install docs by hand to be able to run fdupes on it
mkdir -pv %{buildroot}%{_datadir}/doc/packages/%{name}-doc
cp -r build/sphinx/html %{buildroot}%{_datadir}/doc/packages/%{name}-doc
%fdupes -s %{buildroot}%{_datadir}/doc/packages/%{name}-doc
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
%python_exec %{_bindir}/nosetests -v

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{python_sitelib}/*

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc %{_datadir}/doc/packages/%{name}-doc

%changelog
* Sat Dec  9 2017 arun@gmx.de
- update to version 1.5.9:
  * Dropped CPython 2.6 testing.
- changes from version 1.5.8:
  * Bugfixes
    + Added SortedList.reverse to override MutableSequence.reverse and
    raise NotImplementedError.
* Sat Jul 15 2017 aloisio@gmx.com
- Update to version 1.5.7
  * Changed ``SortedList.__setitem__`` to support slices with stop
    less than start and step equal one.
  1.5.6:
  * Changed ``SortedList.__setitem__`` to support slices that alias
    itself.
  1.5.5:
  * Changed ``SortedList.extend`` to support empty iterables.
  1.5.4:
  * Changed ``SortedList.__new__`` to call
    ``SortedListWithKey.__init__`` once instead of twice.
- Build HTML documentation and put it into -doc subpackage
- Enabled tests
- Converted to singlespec
* Sun Oct  2 2016 toddrme2178@gmail.com
- Update to 1.5.3
  * No upstream changelog
* Tue Dec  9 2014 toddrme2178@gmail.com
- Initial version
